
'''
This file is automatically generated by setup.py, So don't edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.10.4.post1',
    'branch_nick': '(detached',
    'revision_id': '2d0a39f6e4ddb36ea32bf125d91ac367d87fec96',
    'revno': 4886
}
